@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998-2012 Peter Miller
+// Copyright (C) 1998-2013 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -340,7 +340,7 @@ srecord::arglex_tool::get_simple_input(void)
 
     case token_guess:
         token_next();
-        ifp = input_file::guess(fn);
+        ifp = input_file::guess(fn, *this);
         break;
 
     case token_hexdump:
